Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/vl53l1x_simpletest.py
    :caption: examples/vl53l1x_simpletest.py
    :linenos:

Use set_address to update the I2C address of additional connected sensors.

.. literalinclude:: ../examples/vl53l1x_set_address_multiple_sensors.py
    :caption: examples/vl53l1x_set_address_multiple_sensors.py
    :linenos:
